# Customizing Test Data Generation

Synthetic test generation can save a lot of time and effort in creating test datasets for evaluating AI applications. We are working on adding more support to customized test set generation. If you have any specific requirements or would like to collaborate on this, please [talk to us](https://cal.com/shahul-ragas/30min).